@@ -6,6 +6,12 @@
 #
 # GPL-2 or later
 
+## Works around the marvel that is version 6.1.0
+if (dir.exists("~/.R/cache/roxygen2")) {
+    cat("** Using cached version 6.0.1 of roxygen2.\n")
+    .libPaths("~/.R/cache")
+}
+
 ## load roxygen
 library(roxygen2)
 
